@@ -14,9 +14,9 @@ use strict;
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Fri Apr 20 12:24:01 Local time zone must be set--see zic manual page 2007
+## Configuration time: Fri Jun 20 16:39:24 Local time zone must be set--see zic manual page 2008
 ## Configured by     : Gentoo
-## Target system     : linux timberdoodle 2.6.16.9 #3 smp mon apr 24 11:23:17 pdt 2006 ppc power5 (gr) gnulinux 
+## Target system     : linux rooster 2.6.21-gentoo-r4 #1 smp fri aug 31 08:20:33 pdt 2007 ppc64 power5+ (gs) chrp ibm,9133-55a gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -124,8 +124,8 @@ ccname='gcc'
 ccsymbols='__gnu_linux__=1 __linux=1 __linux__=1 __unix=1 __unix__=1 system=linux system=posix system=unix'
 ccversion=''
 cf_by='Gentoo'
-cf_email='Gentoo@timberdoodle.ppc64.dev.gentoo.org'
-cf_time='Fri Apr 20 12:24:01 Local time zone must be set--see zic manual page 2007'
+cf_email='Gentoo@rooster.ppc64.dev.gentoo.org'
+cf_time='Fri Jun 20 16:39:24 Local time zone must be set--see zic manual page 2008'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -146,13 +146,12 @@ config_arg18='-Dman1ext=1'
 config_arg19='-Dman3ext=3pm'
 config_arg1='-des'
 config_arg20='-Dinc_version_list=5.8.0 5.8.0/powerpc-linux 5.8.2 5.8.2/powerpc-linux 5.8.4 5.8.4/powerpc-linux 5.8.5 5.8.5/powerpc-linux 5.8.6 5.8.6/powerpc-linux 5.8.7 5.8.7/powerpc-linux '
-config_arg21='-Dinc_version_list=5.8.0 5.8.0/powerpc-linux 5.8.2 5.8.2/powerpc-linux 5.8.4 5.8.4/powerpc-linux 5.8.5 5.8.5/powerpc-linux 5.8.6 5.8.6/powerpc-linux 5.8.7 5.8.7/powerpc-linux '
-config_arg22='-Dcf_by=Gentoo'
-config_arg23='-Ud_csh'
-config_arg24='-Dusenm'
-config_arg25='-Ui_ndbm'
-config_arg26='-Ui_gdbm'
-config_arg27='-Ui_db'
+config_arg21='-Dcf_by=Gentoo'
+config_arg22='-Ud_csh'
+config_arg23='-Dusenm'
+config_arg24='-Ui_ndbm'
+config_arg25='-Ui_gdbm'
+config_arg26='-Ui_db'
 config_arg2='-Darchname=powerpc-linux'
 config_arg3='-Dcccdlflags=-fPIC'
 config_arg4='-Dccdlflags=-rdynamic'
@@ -161,8 +160,8 @@ config_arg6='-Dprefix=/usr'
 config_arg7='-Dvendorprefix=/usr'
 config_arg8='-Dsiteprefix=/usr'
 config_arg9='-Dlocincpth= '
-config_argc='27'
-config_args='-des -Darchname=powerpc-linux -Dcccdlflags=-fPIC -Dccdlflags=-rdynamic -Dcc=powerpc-unknown-linux-gnu-gcc -Dprefix=/usr -Dvendorprefix=/usr -Dsiteprefix=/usr -Dlocincpth=  -Doptimize=-O1 -mcpu=powerpc -mtune=powerpc -fno-strict-aliasing -pipe -Duselargefiles -Dd_semctl_semun -Dscriptdir=/usr/bin -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dinstallman1dir=/usr/share/man/man1 -Dinstallman3dir=/usr/share/man/man3 -Dman1ext=1 -Dman3ext=3pm -Dinc_version_list=5.8.0 5.8.0/powerpc-linux 5.8.2 5.8.2/powerpc-linux 5.8.4 5.8.4/powerpc-linux 5.8.5 5.8.5/powerpc-linux 5.8.6 5.8.6/powerpc-linux 5.8.7 5.8.7/powerpc-linux  -Dinc_version_list=5.8.0 5.8.0/powerpc-linux 5.8.2 5.8.2/powerpc-linux 5.8.4 5.8.4/powerpc-linux 5.8.5 5.8.5/powerpc-linux 5.8.6 5.8.6/powerpc-linux 5.8.7 5.8.7/powerpc-linux  -Dcf_by=Gentoo -Ud_csh -Dusenm -Ui_ndbm -Ui_gdbm -Ui_db'
+config_argc='26'
+config_args='-des -Darchname=powerpc-linux -Dcccdlflags=-fPIC -Dccdlflags=-rdynamic -Dcc=powerpc-unknown-linux-gnu-gcc -Dprefix=/usr -Dvendorprefix=/usr -Dsiteprefix=/usr -Dlocincpth=  -Doptimize=-O1 -mcpu=powerpc -mtune=powerpc -fno-strict-aliasing -pipe -Duselargefiles -Dd_semctl_semun -Dscriptdir=/usr/bin -Dman1dir=/usr/share/man/man1 -Dman3dir=/usr/share/man/man3 -Dinstallman1dir=/usr/share/man/man1 -Dinstallman3dir=/usr/share/man/man3 -Dman1ext=1 -Dman3ext=3pm -Dinc_version_list=5.8.0 5.8.0/powerpc-linux 5.8.2 5.8.2/powerpc-linux 5.8.4 5.8.4/powerpc-linux 5.8.5 5.8.5/powerpc-linux 5.8.6 5.8.6/powerpc-linux 5.8.7 5.8.7/powerpc-linux  -Dcf_by=Gentoo -Ud_csh -Dusenm -Ui_ndbm -Ui_gdbm -Ui_db'
 contains='grep'
 cp='cp'
 cpio=''
@@ -174,7 +173,7 @@ cpplast='-'
 cppminus='-'
 cpprun='powerpc-unknown-linux-gnu-gcc -E'
 cppstdin='powerpc-unknown-linux-gnu-gcc -E'
-cppsymbols='_BIG_ENDIAN=1 __BIG_ENDIAN__=1 __ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=4 __GNUC__=4 __GNUC_MINOR__=1 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _POSIX_C_SOURCE=200112L _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __linux=1 __linux__=1 __unix=1 __unix__=1'
+cppsymbols='_BIG_ENDIAN=1 __BIG_ENDIAN__=1 __ELF__=1 _FILE_OFFSET_BITS=64 __GLIBC__=2 __GLIBC_MINOR__=5 __GNUC__=4 __GNUC_MINOR__=1 __GNU_LIBRARY__=6 _LARGEFILE_SOURCE=1 _POSIX_C_SOURCE=200112L _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_FILE_OFFSET64=1 __USE_LARGEFILE=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __linux=1 __linux__=1 __unix=1 __unix__=1'
 crypt_r_proto='0'
 cryptlib=''
 csh='csh'
@@ -640,7 +639,7 @@ full_csh='csh'
 full_sed='/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='4.1.1 (Gentoo 4.1.1)'
+gccversion='4.1.1 (Gentoo 4.1.1-r3)'
 getgrent_r_proto='0'
 getgrgid_r_proto='0'
 getgrnam_r_proto='0'
@@ -668,7 +667,7 @@ gidtype='gid_t'
 glibpth='/usr/shlib  /lib /usr/lib /usr/lib/386 /lib/386 /usr/ccs/lib /usr/ucblib /usr/local/lib '
 gmake='gmake'
 gmtime_r_proto='0'
-gnulibc_version='2.4'
+gnulibc_version='2.5'
 grep='grep'
 groupcat='cat /etc/group'
 groupstype='gid_t'
@@ -818,7 +817,7 @@ ldflags_uselargefiles=''
 ldlibpthname='LD_LIBRARY_PATH'
 less='less'
 lib_ext='.a'
-libc='/lib/libc-2.4.so'
+libc='/lib/libc-2.5.so'
 libperl='libperl.a'
 libpth='/usr/local/lib /lib /usr/lib'
 libs='-lpthread -lnsl -lgdbm -ldb -ldl -lm -lcrypt -lutil -lc'
@@ -865,10 +864,10 @@ modetype='mode_t'
 more='more'
 multiarch='undef'
 mv=''
-myarchname='ppc-linux'
+myarchname='ppc64-linux'
 mydomain='.ppc64.dev.gentoo.org'
-myhostname='timberdoodle'
-myuname='linux timberdoodle 2.6.16.9 #3 smp mon apr 24 11:23:17 pdt 2006 ppc power5 (gr) gnulinux '
+myhostname='rooster'
+myuname='linux rooster 2.6.21-gentoo-r4 #1 smp fri aug 31 08:20:33 pdt 2007 ppc64 power5+ (gs) chrp ibm,9133-55a gnulinux '
 n='-n'
 need_va_copy='define'
 netdb_hlen_type='size_t'
@@ -895,7 +894,7 @@ old_pthread_create_joinable=''
 optimize='-O1 -mcpu=powerpc -mtune=powerpc -fno-strict-aliasing -pipe'
 orderlib='false'
 osname='linux'
-osvers='2.6.16.9'
+osvers='2.6.21-gentoo-r4'
 otherlibdirs=' '
 package='perl5'
 pager='/usr/bin/less'
@@ -905,7 +904,7 @@ path_sep=':'
 perl5='/usr/bin/perl'
 perl=''
 perl_patchlevel=''
-perladmin='Gentoo@timberdoodle.ppc64.dev.gentoo.org'
+perladmin='Gentoo@rooster.ppc64.dev.gentoo.org'
 perllibs='-lpthread -lnsl -ldl -lm -lcrypt -lutil -lc'
 perlpath='/usr/bin/perl'
 pg='pg'
